<?php
/**
 * Trvl functions and definitions
 *
 * @package Trvl
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 690; /* pixels */

if ( ! function_exists( 'trvl_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features.
 */
function trvl_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on Trvl, use a find and replace
	 * to change 'trvl' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'trvl', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'image', 'quote', 'link', 'audio', 'status', 'video', ) );

	/**
	 * This theme uses wp_nav_menu() in the footer.
	 */
	register_nav_menu( 'primary', __( 'Footer Navigation Menu', 'trvl' ) );

	/**
	 * Setup custom backgrounds.
	 */
	add_theme_support( 'custom-background', apply_filters( 'trvl_custom_background_args', array(
		'default-color' => '333333',
		'default-image' => '',
	) ) );
}
endif; // trvl_setup
add_action( 'after_setup_theme', 'trvl_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function trvl_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Footer Widget Area', 'trvl' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'trvl_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function trvl_scripts() {
	wp_enqueue_style( 'trvl-fonts', get_template_directory_uri() . '/fonts/league-gothic.css', array(), '20130708' );

	wp_enqueue_style( 'trvl-style', get_stylesheet_uri() );

	wp_enqueue_script( 'trvl-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	if ( is_singular() && wp_attachment_is_image() )
		wp_enqueue_script( 'trvl-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );

	// Loads JavaScript file with functionality specific to Trvl.
	if ( is_active_sidebar( 'sidebar-1' ) )
		wp_enqueue_script( 'trvl-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery-masonry' ), '20130415', true );

}
add_action( 'wp_enqueue_scripts', 'trvl_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( file_exists( get_template_directory() . '/inc/jetpack.php' ) )
	require get_template_directory() . '/inc/jetpack.php';
